@@ -25,9 +25,9 @@ package ExtendedSimonWardFormat;
 require Ftree::DataParsers::ArrayImporters::CSVArrayImporter;
 use strict;
 use warnings;
-use version; our $VERSION = qv('2.3.29');
+use version; our $VERSION = qv('2.3.30');
 
-use Picture;
+use Ftree::Picture;
 use Ftree::FamilyTreeData;
 use Params::Validate qw(:all);
 use StringUtils;
